@@ -9,7 +9,7 @@
 #ifndef XWIDGETS_CONFIG_CLING_HPP
 #define XWIDGETS_CONFIG_CLING_HPP
 
-#pragma cling add_library_path("C:/bld/xwidgets_1563461802724/_h_env/Library/lib")
+#pragma cling add_library_path("D:/bld/xwidgets_1578742946850/_h_env/Library/lib")
 #pragma cling load("libxwidgets")
 
 #endif
